# -*- coding: utf-8 -*-

# Copyright 2013-2014 Jorge Estrada. 
#
# This file is part of azucar.pythonUtils project. 
# It is subject to the license terms in the 
# LICENSE file found in the top-level directory of this distribution. 
# No part of azucar.pythonUtils project, including this file, may be copied,
# modified, propagated, or distributed except according to the terms contained 
# in the LICENSE file.

from xml.dom.minidom import parse
import xml.dom

class ConfigReader:
  """A property container, whose properties are obtained from an XML file.
  """
  
  def __init__(self, configFile):
    """Create a container from the file with name configFile.    
    
    :param configFile: Name of the XML file containing the properties.
    """
    
    self.dom = parse(configFile)
  
  def __getattr__(self, name):
    """Obtain any property as an instance attribute.
    
    :param name: Property name.
    """
    
    realname = name
    if name.startswith("OCTAL"):
      realname = name[5:]
    elements = self.dom.getElementsByTagName(realname)
    # remove all non-text nodes
    for child in elements[0].childNodes:
      if not child.nodeType == xml.dom.Node.TEXT_NODE:
        elements[0].removeChild(child)
    # end loop
    
    elements[0].normalize()
    attribute = elements[0].firstChild.nodeValue.strip()
    if (name.startswith("OCTAL")):
      self.__dict__[name] = int(attribute.encode('latin-1'), 8)
    else :
      if (attribute.encode('latin-1').lower() == "true"):
        self.__dict__[name] = True
      elif (attribute.encode('latin-1').lower() == "false"):
        self.__dict__[name] = False
      else:
        self.__dict__[name] = attribute.encode('latin-1')
    return self.__dict__[name]
# end ConfigReader

