# -*- coding: utf-8 -*-

# Copyright 2013-2014 Jorge Estrada. 
#
# This file is part of azucar.pythonUtils project. 
# It is subject to the license terms in the 
# LICENSE file found in the top-level directory of this distribution. 
# No part of azucar.pythonUtils project, including this file, may be copied,
# modified, propagated, or distributed except according to the terms contained 
# in the LICENSE file.

from lxml import etree
import datetime

TIME_FORMAT_STR = '%Y-%b-%d %H:%M:%S.%f'

class ProvenanceData:
    def __init__(self, applicationName, version):
        self.applicationName = applicationName
        self.startTime = None
        self.endTime = None
        self.version = version

    def createXMLStructure(self):
        root = etree.Element("provenance")
        etree.SubElement(root, "applicationName").text = self.applicationName
        etree.SubElement(root, "startTime").text = self.startTime.strftime(TIME_FORMAT_STR)
        etree.SubElement(root, "endTime").text = self.endTime.strftime(TIME_FORMAT_STR)
        
        elapsedTime = self.endTime - self.startTime
        
        etree.SubElement(root, "executionTime").text = str(elapsedTime)
        etree.SubElement(root, "version").text = self.version
        
        return root
    
    def writeToFile(self, provenanceFilename):
        root = self.createXMLStructure()
        
        etree.ElementTree(root).write(provenanceFilename, pretty_print=True, 
                                      xml_declaration=True, encoding="utf-8")
