#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2013-2014 Jorge Estrada. 
#
# This file is part of azucar.pythonUtils project. 
# It is subject to the license terms in the 
# LICENSE file found in the top-level directory of this distribution. 
# No part of azucar.pythonUtils project, including this file, may be copied,
# modified, propagated, or distributed except according to the terms contained 
# in the LICENSE file.

import azucar.util

version_string = azucar.util.__version__

import argparse
import uuid

TEMPLATE = """# -*- coding: utf-8 -*-

from sqlalchemy.sql import text

IDENTIFIER = "%s"
PREVIOUS_SCRIPT = %s
SCHEMA_VERSION = "?.?"

def stamp_version(connection):
  result = connection.execute(text("DELETE FROM DbVersion"))
  result.close()

  command = text("INSERT INTO DbVersion(schema_version, script_version) VALUES (:schema_version, :script_version)")
  result = connection.execute(command, schema_version=SCHEMA_VERSION,
                     script_version=IDENTIFIER)
  result.close()

def upgrade(connection):
  pass

def downgrade(connection):
  pass
"""

def main(args):
    id = uuid.uuid4()
    new_filename = "%s_%s.db.py" % (id, args.description)
    
    with open(new_filename, "w") as output:
        if args.previous_script:
            previous_value = '"%s"' % args.previous_script
        else:
            previous_value = None

        output.write(TEMPLATE % (id, previous_value))
        output.write('\n')

def configureArgumentParser():
  parser = argparse.ArgumentParser(description='Create a templated DB upgrade script.')
  parser.add_argument('--version', action='version', version=version_string)
  parser.add_argument('description', help='A string describing the script, to be used as part of the script file name..')
  parser.add_argument('previous_script', help='File name of the DB upgrade script immediately preceding this. If this is the first script, then ommit this argument.', nargs='?', default=None)

  return parser


if __name__ == "__main__":
    parser = configureArgumentParser()
    args = parser.parse_args()

    main(args)
