#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2013-2014 Jorge Estrada. 
#
# This file is part of azucar.pythonUtils project. 
# It is subject to the license terms in the 
# LICENSE file found in the top-level directory of this distribution. 
# No part of azucar.pythonUtils project, including this file, may be copied,
# modified, propagated, or distributed except according to the terms contained 
# in the LICENSE file.

import argparse
import json

import azucar.util

version_string = azucar.util.__version__

from azucar.db_utils import connect_to_database, drop_table, get_tables

def main(args):
    connection_data = read_json_configuration_file(args.config_file)

    db_engine = connect_to_database(connection_data["user"], 
                                    connection_data["passwd"], 
                                    connection_data["db"])

    conn = db_engine.connect()
    
    list_of_tables = get_tables(conn)

    # Disable foreign key checks (only in session, only in InnoDB,
    # should work in any other engine).
    conn.execute("SET FOREIGN_KEY_CHECKS = 0")

    try: 
        for table_name in list_of_tables:
            drop_table(conn, table_name)
    finally:
        # reenable foreign keys
        conn.execute("SET FOREIGN_KEY_CHECKS = 1")
    

def read_json_configuration_file(filename):
    with open(filename, "r") as input:
        result = json.load(input, encoding='utf-8')

    return result


def configureArgumentParser():
  parser = argparse.ArgumentParser(description='Drop database table schema.')
  parser.add_argument('--version', action='version', version=version_string)
  parser.add_argument('--config_file', help='JSON file with the database connection configuration.', default='db_config.json')

  return parser


if __name__ == "__main__":
    parser = configureArgumentParser()
    args = parser.parse_args()

    main(args)
